from flask import Flask, render_template, request

app = Flask(__name__)

# Dummy list of user IDs
user_ids = ['2EK76PP050', '3UH38PM420', '4OL21FC153']

@app.route('/', methods=['GET', 'POST'])
def index():
    message = None
    message_class = None
    
    if request.method == 'POST':
        search_query = request.form['search_query']
        
        # Validate the input format
        if not validate_input(search_query):
            message = 'Invalid input format. Please enter a valid USN.'
            message_class = 'invalid'
        else:
            # Perform search based on the entered query
            if search_query.upper() in [user_id.upper() for user_id in user_ids]:
                message = 'ID found: {}'.format(search_query)
                message_class = 'found'
            else:
                message = 'ID not found: {}'.format(search_query)
                message_class = 'not-found'
    
    return render_template('index.html', message=message, message_class=message_class)

def validate_input(input_str):
    if len(input_str) != 10:
        return False
    
    try:
        first_digit = int(input_str[0])
    except ValueError:
        return False
    
    if first_digit < 1 or first_digit > 4:
        return False
    
    if not input_str[1:3].isupper():
        return False
    
    if not input_str[3:5].isdigit():
        return False
    
    if not input_str[5:7].isupper():
        return False
    
    if not input_str[7:].isdigit():
        return False
    
    return True



if __name__ == '__main__':
    app.run(debug=True)
