from flask import Flask, render_template, request, jsonify
import json
import os

app = Flask(__name__)
DATA_FILE = 'data.json'

def read_data():
    if os.path.exists(DATA_FILE):
        with open(DATA_FILE, 'r') as file:
            return json.load(file)
    return []

def write_data(data):
    try:
        with open(DATA_FILE, 'w') as file:
            json.dump(data, file, indent=4)
        print(f"Data successfully written to {DATA_FILE}")
    except Exception as e:
        print(f"Error writing to {DATA_FILE}: {e}")

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/submit', methods=['POST'])
def submit():
    data = request.get_json()
    username = data.get('username')
    phone = data.get('phone')
    email = data.get('email')

    # Read existing data
    existing_data = read_data()

    # Append new data
    new_entry = {'username': username, 'phone': phone, 'email': email}
    existing_data.append(new_entry)

    # Write updated data back to file
    write_data(existing_data)

    return jsonify({'status': 'success', 'username': username, 'phone': phone, 'email': email})

if __name__ == '__main__':
    app.run(debug=True)
